#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monadLib
version:              3.10
visibility:           public
id:                   monadLib-3.10-Dun6nxvKGiU3h2oOwCB6v6
key:                  monadLib-3.10-Dun6nxvKGiU3h2oOwCB6v6
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/monadlib
synopsis:             A collection of monad transformers.
description:          A collection of monad transformers.
category:             Monads
abi:                  da9a2c3551a47212bed33bbef5636ae6
exposed:              True
exposed-modules:      MonadLib MonadLib.Derive MonadLib.Monads
import-dirs:          /usr/lib/ghc-8.10.5/site-local/monadLib-3.10
library-dirs:         /usr/lib/ghc-8.10.5/site-local/monadLib-3.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/monadLib-3.10
hs-libraries:         HSmonadLib-3.10-Dun6nxvKGiU3h2oOwCB6v6
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-monadlib/html/monadLib.haddock
haddock-html:         /usr/share/doc/haskell-monadlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

